@@ -133,7 +133,7 @@ static GdkColor default_link_color = { 0, 0, 0, 0xeeee };
 static GdkColor default_visited_link_color = { 0, 0x5555, 0x1a1a, 0x8b8b };
 
 
-G_DEFINE_TYPE (GdictDefbox, gdict_defbox, GTK_TYPE_VBOX);
+G_DEFINE_TYPE (GdictDefbox, gdict_defbox, GTK_TYPE_BOX);
 
 
 static Definition *
@@ -397,7 +397,7 @@ exact_prefix_cmp (const gchar *string,
 	/* If string contains prefix, check that prefix is not followed
 	 * by a unicode mark symbol, e.g. that trailing 'a' in prefix
 	 * is not part of two-char a-with-hat symbol in string. */
-	return type != G_UNICODE_COMBINING_MARK &&
+	return type != G_UNICODE_SPACING_MARK &&
 		type != G_UNICODE_ENCLOSING_MARK &&
 		type != G_UNICODE_NON_SPACING_MARK;
 }
@@ -1145,7 +1145,7 @@ find_prev_clicked_cb (GtkWidget *widget,
   if (priv->hide_timeout)
     {
       g_source_remove (priv->hide_timeout);
-      priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+      priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
     }
 }
 
@@ -1239,7 +1239,7 @@ find_next_clicked_cb (GtkWidget *widget,
   if (priv->hide_timeout)
     {
       g_source_remove (priv->hide_timeout);
-      priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+      priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
     }
 }
 
@@ -1275,7 +1275,7 @@ find_entry_changed_cb (GtkWidget *widget,
   if (priv->hide_timeout)
     {
       g_source_remove (priv->hide_timeout);
-      priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+      priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
     }
 }
 
@@ -1303,24 +1303,36 @@ create_find_pane (GdictDefbox *defbox)
 
   priv = defbox->priv;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  find_pane = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   find_pane = gtk_hbox_new (FALSE, 0);
+#endif
   gtk_container_set_border_width (GTK_CONTAINER (find_pane), 0);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+#else
   hbox1 = gtk_hbox_new (FALSE, 6);
+#endif
   gtk_box_pack_start (GTK_BOX (find_pane), hbox1, TRUE, TRUE, 0);
   gtk_widget_show (hbox1);
 
   button = gtk_button_new ();
   gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
   gtk_button_set_image (GTK_BUTTON (button),
-                        gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-                                                  GTK_ICON_SIZE_BUTTON));
+                        gtk_image_new_from_icon_name ("window-close",
+                                                      GTK_ICON_SIZE_BUTTON));
   g_signal_connect (button, "clicked",
                     G_CALLBACK (close_button_clicked), defbox);
   gtk_box_pack_start (GTK_BOX (hbox1), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+#else
   hbox2 = gtk_hbox_new (FALSE, 12);
+#endif
   gtk_box_pack_start (GTK_BOX (hbox1), hbox2, TRUE, TRUE, 0);
   gtk_widget_show (hbox2);
 
@@ -1333,22 +1345,26 @@ create_find_pane (GdictDefbox *defbox)
   gtk_box_pack_start (GTK_BOX (hbox2), priv->find_entry, TRUE, TRUE, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), priv->find_entry);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  sep = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
+#else
   sep = gtk_vseparator_new ();
+#endif
   gtk_box_pack_start (GTK_BOX (hbox1), sep, FALSE, FALSE, 0);
   gtk_widget_show (sep);
 
   priv->find_prev = gtk_button_new_with_mnemonic (_("_Previous"));
   gtk_button_set_image (GTK_BUTTON (priv->find_prev),
-  			gtk_image_new_from_stock (GTK_STOCK_GO_BACK,
-  						  GTK_ICON_SIZE_MENU));
+                        gtk_image_new_from_icon_name ("go-previous",
+                                                      GTK_ICON_SIZE_MENU));
   g_signal_connect (priv->find_prev, "clicked",
   		    G_CALLBACK (find_prev_clicked_cb), defbox);
   gtk_box_pack_start (GTK_BOX (hbox1), priv->find_prev, FALSE, FALSE, 0);
 
   priv->find_next = gtk_button_new_with_mnemonic (_("_Next"));
   gtk_button_set_image (GTK_BUTTON (priv->find_next),
-  			gtk_image_new_from_stock (GTK_STOCK_GO_FORWARD,
-  						  GTK_ICON_SIZE_MENU));
+                        gtk_image_new_from_icon_name ("go-next",
+                                                      GTK_ICON_SIZE_MENU));
   g_signal_connect (priv->find_next, "clicked",
   		    G_CALLBACK (find_next_clicked_cb), defbox);
   gtk_box_pack_start (GTK_BOX (hbox1), priv->find_next, FALSE, FALSE, 0);
@@ -1638,6 +1654,9 @@ gdict_defbox_constructor (GType                  type,
   gtk_widget_push_composite_child ();
 
   sw = gtk_scrolled_window_new (NULL, NULL);
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtk_widget_set_vexpand (sw, TRUE);
+#endif
   gtk_widget_set_composite_name (sw, "gdict-defbox-scrolled-window");
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
   				  GTK_POLICY_AUTOMATIC,
@@ -1736,7 +1755,7 @@ gdict_defbox_real_show_find (GdictDefbox *defbox)
 
   gtk_widget_grab_focus (defbox->priv->find_entry);
 
-  defbox->priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+  defbox->priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
 }
 
 static void
@@ -1916,6 +1935,7 @@ gdict_defbox_init (GdictDefbox *defbox)
 {
   GdictDefboxPrivate *priv;
 
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (defbox), GTK_ORIENTATION_VERTICAL);
   gtk_box_set_spacing (GTK_BOX (defbox), 6);
 
   priv = GDICT_DEFBOX_GET_PRIVATE (defbox);
@@ -2108,7 +2128,7 @@ gdict_defbox_set_show_find (GdictDefbox *defbox,
       gtk_widget_grab_focus (priv->find_entry);
 
       if (!priv->hide_timeout)
-        priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+        priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
     }
   else
     {
