@@ -96,7 +96,7 @@ enum
 
 static guint source_chooser_signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE (GdictSourceChooser, gdict_source_chooser, GTK_TYPE_VBOX);
+G_DEFINE_TYPE (GdictSourceChooser, gdict_source_chooser, GTK_TYPE_BOX);
 
 static void
 gdict_source_chooser_finalize (GObject *gobject)
@@ -129,7 +129,11 @@ gdict_source_chooser_dispose (GObject *gobject)
 
   if (priv->busy_cursor)
     {
+#if GTK_CHECK_VERSION (3, 0, 0)
+      g_object_unref (priv->busy_cursor);
+#else
       gdk_cursor_unref (priv->busy_cursor);
+#endif
       priv->busy_cursor = NULL;
     }
 
@@ -253,6 +257,9 @@ gdict_source_chooser_constructor (GType                  gtype,
   gtk_widget_push_composite_child ();
 
   sw = gtk_scrolled_window_new (NULL, NULL);
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtk_widget_set_vexpand (sw, TRUE);
+#endif
   gtk_widget_set_composite_name (sw, "gdict-source-chooser-scrolled-window");
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
                                   GTK_POLICY_AUTOMATIC,
@@ -283,13 +290,17 @@ gdict_source_chooser_constructor (GType                  gtype,
   gtk_container_add (GTK_CONTAINER (sw), priv->treeview);
   gtk_widget_show (priv->treeview);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+#else
   hbox = gtk_hbox_new (FALSE, 6);
+#endif
   priv->buttons_box = hbox;
 
   priv->refresh_button = gtk_button_new ();
   gtk_button_set_image (GTK_BUTTON (priv->refresh_button),
-                        gtk_image_new_from_stock (GTK_STOCK_REFRESH,
-                                                  GTK_ICON_SIZE_BUTTON));
+                        gtk_image_new_from_icon_name ("view-refresh",
+                                                      GTK_ICON_SIZE_BUTTON));
   g_signal_connect (priv->refresh_button,
                     "clicked", G_CALLBACK (refresh_button_clicked_cb),
                     chooser);
@@ -396,6 +407,7 @@ gdict_source_chooser_init (GdictSourceChooser *chooser)
 {
   GdictSourceChooserPrivate *priv;
 
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (chooser), GTK_ORIENTATION_VERTICAL);
   chooser->priv = priv = GDICT_SOURCE_CHOOSER_GET_PRIVATE (chooser);
 
   priv->store = gtk_list_store_new (SOURCE_N_COLUMNS,
