@@ -108,7 +108,7 @@ static guint db_chooser_signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GdictStrategyChooser,
                gdict_strategy_chooser,
-               GTK_TYPE_VBOX);
+               GTK_TYPE_BOX);
 
 
 static void
@@ -328,6 +328,9 @@ gdict_strategy_chooser_constructor (GType                  type,
   gtk_widget_push_composite_child ();
 
   sw = gtk_scrolled_window_new (NULL, NULL);
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtk_widget_set_vexpand (sw, TRUE);
+#endif
   gtk_widget_set_composite_name (sw, "gdict-strategy-chooser-scrolled-window");
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 		  		  GTK_POLICY_AUTOMATIC,
@@ -354,12 +357,16 @@ gdict_strategy_chooser_constructor (GType                  type,
   gtk_container_add (GTK_CONTAINER (sw), priv->treeview);
   gtk_widget_show (priv->treeview);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   hbox = gtk_hbox_new (FALSE, 0);
+#endif
 
   priv->refresh_button = gtk_button_new ();
   gtk_button_set_image (GTK_BUTTON (priv->refresh_button),
-		        gtk_image_new_from_stock (GTK_STOCK_REFRESH,
-						  GTK_ICON_SIZE_SMALL_TOOLBAR));
+                        gtk_image_new_from_icon_name ("view-refresh",
+                                                      GTK_ICON_SIZE_SMALL_TOOLBAR));
   g_signal_connect (priv->refresh_button, "clicked",
 		    G_CALLBACK (refresh_button_clicked_cb),
 		    chooser);
@@ -370,8 +377,8 @@ gdict_strategy_chooser_constructor (GType                  type,
 
   priv->clear_button = gtk_button_new ();
   gtk_button_set_image (GTK_BUTTON (priv->clear_button),
-		        gtk_image_new_from_stock (GTK_STOCK_CLEAR,
-						  GTK_ICON_SIZE_SMALL_TOOLBAR));
+                        gtk_image_new_from_icon_name ("edit-clear",
+                                                      GTK_ICON_SIZE_SMALL_TOOLBAR));
   g_signal_connect (priv->clear_button, "clicked",
 		    G_CALLBACK (clear_button_clicked_cb),
 		    chooser);
@@ -441,6 +448,7 @@ gdict_strategy_chooser_init (GdictStrategyChooser *chooser)
 {
   GdictStrategyChooserPrivate *priv;
 
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (chooser), GTK_ORIENTATION_VERTICAL);
   chooser->priv = priv = GDICT_STRATEGY_CHOOSER_GET_PRIVATE (chooser);
 
   priv->results = -1;
