@@ -333,8 +333,12 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_container_add (GTK_CONTAINER (window), frame);
   gtk_widget_show (frame);
   priv->frame = frame;
-  
+
+#if GTK_CHECK_VERSION (3, 0, 0)
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
+#else
   vbox = gtk_vbox_new (FALSE, 12);
+#endif
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
   gtk_widget_show (vbox);
@@ -347,8 +351,12 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_widget_show (priv->defbox);
   gtk_widget_set_can_focus (priv->defbox, TRUE);
   gtk_widget_set_can_default (priv->defbox, TRUE);
-  
+
+#if GTK_CHECK_VERSION (3, 0, 0)
+  bbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
+#else
   bbox = gtk_hbutton_box_new ();
+#endif
   gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
   gtk_box_set_spacing (GTK_BOX (bbox), 6);
   gtk_box_pack_end (GTK_BOX (vbox), bbox, FALSE, FALSE, 0);
@@ -508,6 +516,9 @@ gdict_applet_draw (GdictApplet *applet)
   if (priv->box)
     gtk_widget_destroy (priv->box);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  box = gtk_box_new (priv->orient, 0);
+#else
   switch (priv->orient)
     {
     case GTK_ORIENTATION_VERTICAL:
@@ -520,6 +531,7 @@ gdict_applet_draw (GdictApplet *applet)
       g_assert_not_reached ();
       break;
     }
+#endif
   
   gtk_container_add (GTK_CONTAINER (applet), box);
   gtk_widget_show (box);
@@ -542,7 +554,11 @@ gdict_applet_draw (GdictApplet *applet)
   gtk_box_pack_start (GTK_BOX (box), priv->toggle, FALSE, FALSE, 0);
   gtk_widget_show (priv->toggle);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
   hbox = gtk_hbox_new (FALSE, 0);
+#endif
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 0);
   gtk_container_add (GTK_CONTAINER (priv->toggle), hbox);
   gtk_widget_show (hbox);
@@ -571,9 +587,8 @@ gdict_applet_draw (GdictApplet *applet)
       priv->image = gtk_image_new ();
 
       gtk_image_set_pixel_size (GTK_IMAGE (priv->image), priv->size - 10);
-      gtk_image_set_from_stock (GTK_IMAGE (priv->image),
-				GTK_STOCK_MISSING_IMAGE,
-				-1);
+      gtk_image_set_from_icon_name (GTK_IMAGE (priv->image),
+                                    "image-missing", -1);
       
       gtk_box_pack_start (GTK_BOX (hbox), priv->image, FALSE, FALSE, 0);
       gtk_widget_show (priv->image);
