@@ -321,7 +321,12 @@ create_effects_frame (GtkWidget   *outer_vbox,
   GtkWidget *combo;
   gchar *title;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  main_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+#else
   main_vbox = gtk_vbox_new (FALSE, 6);
+#endif
+  gtk_widget_set_sensitive (main_vbox, !take_area_shot);
   gtk_box_pack_start (GTK_BOX (outer_vbox), main_vbox, FALSE, FALSE, 0);
   gtk_widget_show (main_vbox);
   effects_vbox = main_vbox;
@@ -329,12 +334,21 @@ create_effects_frame (GtkWidget   *outer_vbox,
   title = g_strconcat ("<b>", frame_title, "</b>", NULL);
   label = gtk_label_new (title);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
   gtk_box_pack_start (GTK_BOX (main_vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   g_free (title);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+#else
   hbox = gtk_hbox_new (FALSE, 12);
+#endif
   gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
@@ -343,7 +357,11 @@ create_effects_frame (GtkWidget   *outer_vbox,
   gtk_box_pack_start (GTK_BOX (hbox), align, FALSE, FALSE, 0);
   gtk_widget_show (align);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+#else
   vbox = gtk_vbox_new (FALSE, 6);
+#endif
   gtk_container_add (GTK_CONTAINER (align), vbox);
   gtk_widget_show (vbox);
 
@@ -368,13 +386,22 @@ create_effects_frame (GtkWidget   *outer_vbox,
   border_check = check;
 
   /** Effects **/
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+#else
   hbox = gtk_hbox_new (FALSE, 12);
+#endif
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
   label = gtk_label_new_with_mnemonic (_("Apply _effect:"));
   gtk_widget_set_sensitive (label, take_window_shot);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   effect_label = label;
@@ -401,19 +428,32 @@ create_screenshot_frame (GtkWidget   *outer_vbox,
   GSList *group;
   gchar *title;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  main_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+#else
   main_vbox = gtk_vbox_new (FALSE, 6);
+#endif
   gtk_box_pack_start (GTK_BOX (outer_vbox), main_vbox, FALSE, FALSE, 0);
   gtk_widget_show (main_vbox);
 
   title = g_strconcat ("<b>", frame_title, "</b>", NULL);
   label = gtk_label_new (title);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
   gtk_box_pack_start (GTK_BOX (main_vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
   g_free (title);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+#else
   hbox = gtk_hbox_new (FALSE, 12);
+#endif
   gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
@@ -427,7 +467,11 @@ create_screenshot_frame (GtkWidget   *outer_vbox,
   gtk_container_add (GTK_CONTAINER (align), image);
   gtk_widget_show (image);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+#else
   vbox = gtk_vbox_new (FALSE, 6);
+#endif
   gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
   gtk_widget_show (vbox);
 
@@ -468,7 +512,12 @@ create_screenshot_frame (GtkWidget   *outer_vbox,
   gtk_widget_show (radio);
 
   /** Grab after delay **/
+#if GTK_CHECK_VERSION (3, 0, 0)
+  delay_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+#else
   delay_hbox = gtk_hbox_new (FALSE, 6);
+#endif
+  gtk_widget_set_sensitive (delay_hbox, !take_area_shot);
   gtk_box_pack_start (GTK_BOX (vbox), delay_hbox, FALSE, FALSE, 0);
   gtk_widget_show (delay_hbox);
 
@@ -476,7 +525,12 @@ create_screenshot_frame (GtkWidget   *outer_vbox,
    * delay of <spin button> seconds".
    */
   label = gtk_label_new_with_mnemonic (_("Grab _after a delay of"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
   gtk_box_pack_start (GTK_BOX (delay_hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -496,7 +550,12 @@ create_screenshot_frame (GtkWidget   *outer_vbox,
    * delay of <spin button> seconds".
    */
   label = gtk_label_new (_("seconds"));
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
   gtk_box_pack_end (GTK_BOX (delay_hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 }
@@ -516,7 +575,11 @@ create_interactive_dialog (void)
   gtk_window_set_title (GTK_WINDOW (retval), _("Take Screenshot"));
 
   /* main container */
+#if GTK_CHECK_VERSION (3, 0, 0)
+  main_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
+#else
   main_vbox = gtk_vbox_new (FALSE, 18);
+#endif
   gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 5);
   gtk_box_pack_start (GTK_BOX (content_area), main_vbox, TRUE, TRUE, 0);
   gtk_widget_show (main_vbox);
@@ -888,9 +951,9 @@ build_uri (AsyncExistenceJob *job)
 
   d = g_date_time_new_now_local ();
   /* Translators: This is a strftime format string.
-		 * It is used to display the time in 24-hours format (eg, like
-		 * in France: 20:10). */
-  timestamp = g_date_time_format (d, _("%Y-%m-%d %H:%M:%S"));
+   * It is used to display the time in 24-hours format (eg, like
+   * in France: 20:10) but using hyphens in place of colons. */
+  timestamp = g_date_time_format (d, _("%Y-%m-%d %H-%M-%S"));
   g_date_time_unref (d);
 
   if (job->iteration == 0)
